@@ -5,7 +5,6 @@ from boto3.session import Session
 from botocore import xform_name
 
 from mypy_boto3_builder.package_data import BasePackageData
-from mypy_boto3_builder.parsers.boto3_utils import get_boto3_client, get_boto3_resource
 from mypy_boto3_builder.parsers.shape_parser import ShapeParser
 from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.client import Client
@@ -13,6 +12,7 @@ from mypy_boto3_builder.structures.paginator import Paginator
 from mypy_boto3_builder.structures.service_package import ServicePackage
 from mypy_boto3_builder.structures.service_resource import ServiceResource
 from mypy_boto3_builder.structures.waiter import Waiter
+from mypy_boto3_builder.utils.boto3_utils import get_boto3_client, get_boto3_resource
 from mypy_boto3_builder.utils.strings import get_class_prefix
 
 
