@@ -1,9 +1,13 @@
 """
 Annotation to mark argument for removal.
 """
+from typing import TypeVar
+
 from mypy_boto3_builder.import_helpers.import_record import ImportRecord
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 
+_R = TypeVar("_R", bound="RemoveArgument")
+
 
 class RemoveArgument(FakeAnnotation):
     """
@@ -16,7 +20,7 @@ class RemoveArgument(FakeAnnotation):
         """
         return "None"
 
-    def copy(self) -> FakeAnnotation:
+    def copy(self: _R) -> _R:
         """
         Not used.
         """
